@@ -90,7 +90,10 @@ class BookAccessRight(models.Model):
         unique_together = (("book", "holder_id", "holder_type"),)
 
     def __str__(self):
-        return f"{self.holder_obj.readable_name} {self.rights} on {self.book.title}"
+        if self.holder_obj:
+            return f"{self.holder_obj.readable_name} {self.rights} on {self.book.title}"
+        else:
+            return f"{self.holder_type.model} {self.holder_id} {self.rights} on {self.book.title}"
 
 
 class BookStyle(models.Model):
