@@ -8,7 +8,7 @@ export class BookAppItem {
         this.app.routes['books'] = {
             requireLogin: true,
             open: pathnameParts => {
-                const path = decodeURI(('/' + pathnameParts.slice(2).join('/')).replace(/\/?$/, '/'))
+                const path = ('/' + pathnameParts.slice(2).join('/')).replace(/\/?$/, '/')
                 return import("../../modules/books").then(({BookOverview}) => new BookOverview(this.app.config, path))
             },
             dbTables: {
